@@ -30,6 +30,7 @@
 
 import supybot.utils as utils
 from supybot.commands import *
+import supybot.utils.minisix as minisix
 import supybot.plugins as plugins
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
@@ -81,11 +82,11 @@ class MessageParser(callbacks.Plugin, plugins.ChannelDBHandler):
         """Create the database and connect to it."""
         if os.path.exists(filename):
             db = sqlite3.connect(filename)
-            if sys.version_info[0] < 3:
+            if minisix.PY2:
                 db.text_factory = str
             return db
         db = sqlite3.connect(filename)
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             db.text_factory = str
         cursor = db.cursor()
         cursor.execute("""CREATE TABLE triggers (
@@ -174,7 +175,7 @@ class MessageParser(callbacks.Plugin, plugins.ChannelDBHandler):
                         thisaction = action
                         self._updateRank(channel, regexp)
                         for (i, j) in enumerate(match.groups()):
-                            if match.group(i+1):
+                            if match.group(i+1) is not None:
                                 thisaction = re.sub(r'\$' + str(i+1), match.group(i+1), thisaction)
                         actions.append(thisaction)
                         if max_triggers != 0 and max_triggers == len(actions):
