@@ -151,7 +151,7 @@ class Nickometer(callbacks.Plugin):
             nickInitial = nick
             nick=re.sub('^([^()]*)(\()(.*)(\))([^()]*)$', '\1\3\5', nick, 1)
             nick=re.sub('^([^{}]*)(\{)(.*)(\})([^{}]*)$', '\1\3\5', nick, 1)
-            nick=re.sub('^([^[\]]*)(\[)(.*)(\])([^[\]]*)$', '\1\3\5', nick, 1)
+            nick=re.sub('^([^\[\]]*)(\[)(.*)(\])([^\[\]]*)$', '\1\3\5', nick, 1)
             if nick == nickInitial:
                 break
             self.log.debug('Removed some matching brackets %r => %r',
