@@ -397,7 +397,7 @@ class Note(callbacks.Plugin):
             else:
                 temp[note[1]] = [note[0]]
         notes = []
-        for (k,v) in temp.iteritems():
+        for (k,v) in temp.items():
             if '(private)' in k:
                 k = k.replace('(private)', format('%b private', len(v)))
             notes.append(format('%L %s', v, k))
