@@ -33,6 +33,7 @@ from supybot.test import *
 import supybot.conf as conf
 import supybot.utils as utils
 import supybot.ircmsgs as ircmsgs
+import supybot.utils.minisix as minisix
 import supybot.callbacks as callbacks
 
 tokenize = callbacks.tokenize
@@ -76,7 +77,7 @@ class TokenizerTestCase(SupyTestCase):
 def testUnicode(self):
     self.assertEqual(tokenize(u'好'), [u'好'])
     self.assertEqual(tokenize(u'"好"'), [u'好'])"""
-    if sys.version_info[0] >= 3:
+    if minisix.PY3:
         _testUnicode = _testUnicode.replace("u'", "'")
     exec(_testUnicode)
 
@@ -526,7 +527,8 @@ class PrivmsgTestCase(ChannelPluginTestCase):
             original = str(conf.supybot.reply.whenNotCommand)
             conf.supybot.reply.whenNotCommand.set('True')
             self.irc.addCallback(self.BadInvalidCommand(self.irc))
-            self.assertRegexp('asdfjkl', 'not a valid command')
+            self.assertRegexp('asdfjkl', 'not a valid command',
+                    expectException=True)
         finally:
             conf.supybot.reply.whenNotCommand.set(original)
 
