@@ -227,6 +227,9 @@ class FunctionsTestCase(SupyTestCase):
         r = ircutils.wrap(s, 139)
         self.assertTrue(max(map(pred, r)) <= 139)
 
+        s = '\x02\x16 barbazqux' + ('foobarbazqux ' * 20)[0:-1]
+        r = ircutils.wrap(s, 91)
+        self.assertTrue(max(map(pred, r)) <= 91)
 
     def testSafeArgument(self):
         s = 'I have been running for 9 seconds'
