@@ -308,7 +308,7 @@ class StrTest(SupyTestCase):
         self.assertEqual(f('fooba\\rba\\z'), 'foorz')
         f = PRTR('s/cat/dog/i')
         self.assertEqual(f('CATFISH'), 'dogFISH')
-        f = PRTR('s/foo/foo\/bar/')
+        f = PRTR(r's/foo/foo\/bar/')
         self.assertEqual(f('foo'), 'foo/bar')
         f = PRTR('s/^/foo/')
         self.assertEqual(f('bar'), 'foobar')
@@ -326,7 +326,7 @@ class StrTest(SupyTestCase):
         self.assertEqual(f('foobarbaz'), 'barbarbaz')
 
     def testPerlReToReplacerBug850931(self):
-        f = utils.str.perlReToReplacer('s/\b(\w+)\b/\1./g')
+        f = utils.str.perlReToReplacer(r's/\b(\w+)\b/\1./g')
         self.assertEqual(f('foo bar baz'), 'foo. bar. baz.')
 
     def testCommaAndify(self):
@@ -1175,6 +1175,43 @@ class TestTruncatableSet(SupyTestCase):
         s.truncate(3)
         self.assertEqual(s, set(['foo', 'baz', 'qux']))
 
+class UtilsPythonTest(SupyTestCase):
+    def test_dict(self):
+        class Foo:
+            def __hasattr__(self, n):
+                raise Exception(n)
+            def __getattr__(self, n):
+                raise Exception(n)
+
+        def f():
+            self = Foo()
+            self.bar = 'baz'
+            raise Exception('f')
+
+        try:
+            f()
+        except:
+            res = utils.python.collect_extra_debug_data()
+
+        self.assertTrue(re.search('self.bar.*=.*baz', res), res)
+
+    def test_slots(self):
+        class Foo:
+            __slots__ = ('bar',)
+            def __hasattr__(self, n):
+                raise Exception(n)
+            def __getattr__(self, n):
+                raise Exception(n)
+
+        def f():
+            self = Foo()
+            self.bar = 'baz'
+            raise Exception('f')
+
+        try:
+            f()
+        except:
+            res = utils.python.collect_extra_debug_data()
 
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
 
